@@ -12,8 +12,8 @@ cmake ${CMAKE_ARGS} $SRC_DIR/$PKG_NAME_ALIAS \
     -DCMAKE_INSTALL_SYSTEM_RUNTIME_LIBS_SKIP=True \
     -DBUILD_SHARED_LIBS=ON \
     -DCMAKE_BUILD_TYPE=Release \
-    -DCONDA_SP_DIR=$SP_DIR \
     -DSETUPTOOLS_DEB_LAYOUT=OFF \
-    -DPYTHON_EXECUTABLE=$PYTHON
+    -DPYTHON_SITE_PACKAGES_INSTALL_DIR=$SP_DIR \
+    -DPython_EXECUTABLE=$PYTHON
 
 cmake --build . --config Release --target install
